/*
 * pop.h
 * This file is part of LibPOPc
 *
 * Copyright (C) 2022 - Félix Arreola Rodríguez
 *
 * LibPOPc is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * LibPOPc is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with LibPOPc; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 */

#ifndef __POP_H__
#define __POP_H__

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <sys/socket.h>

#define POP_WANT_NONE			0x000
#define POP_WANT_POLL_IN		0x001
#define POP_WANT_POLL_OUT		0x002

enum {
	POP_ERROR = -1,
	POP_POLL = 0,
	POP_SUCCESS = 1
};

enum {
	POP_STATE_CLOSED = 0,
	POP_STATE_TRYING_CONNECT,
	POP_STATE_BANNER,
	POP_STATE_READY_BEFORE_LOGIN,
	POP_STATE_AUTH_LOGIN_USER,
	POP_STATE_AUTH_LOGIN_PASS,
	POP_STATE_READY,
	POP_STATE_CMD,
	POP_STATE_DATA,
	
	POP_STATE_CLOSING,
};

typedef struct _POPSession POPSession;

typedef void (*POPDataFunc) (POPSession *session, const char *line, void *data);

POPSession *pop_session_create (void);
int pop_session_auth_login (POPSession *session, const char *user, const char *passwd);
int pop_session_connect (POPSession *session, struct sockaddr *server, socklen_t addr_len);
void pop_session_close_and_clean (POPSession *session);
int pop_session_send_command (POPSession *session, char *command, int multiline);
int pop_session_send_close (POPSession *session);

int pop_session_continue (POPSession *session, int what);
int pop_session_get_state (POPSession *session);
int pop_session_get_poll (POPSession *session);
int pop_session_get_socket (POPSession *session);
int pop_session_get_last_code (POPSession *session);
char * pop_session_get_last_message (POPSession *session);
void pop_session_free (POPSession *session);

void pop_session_data_func (POPSession *session, POPDataFunc func, void *data);

#endif /* __POP_H__ */

